@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -18,7 +18,7 @@ from beartype.typing import (
     Optional,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._check.checkmagic import (
+from beartype._data.code.datacodename import (
     ARG_NAME_CONF,
     ARG_NAME_EXCEPTION_PREFIX,
     ARG_NAME_GETRANDBITS,
@@ -28,13 +28,17 @@ from beartype._check.checkmagic import (
     CODE_PITH_ROOT_NAME_PLACEHOLDER,
     FUNC_CHECKER_NAME_PREFIX,
 )
-from beartype._check.convert.convsanify import sanify_hint_root_statement
-from beartype._check.code.codemake import make_check_expr
-from beartype._check.error.errorget import (
+from beartype._check.convert.convmain import sanify_hint_root_statement
+from beartype._check.code.codemain import make_check_expr
+from beartype._check.error.errmain import (
     get_func_pith_violation,
     get_hint_object_violation,
 )
-from beartype._check.util.checkutilmake import make_func_signature
+from beartype._check.metadata.hint.hintsane import (
+    HINT_SANE_IGNORABLE,
+    HintSane,
+)
+from beartype._check.signature.sigmake import make_func_signature
 from beartype._check._checksnip import (
     CODE_CHECKER_SIGNATURE,
     CODE_RAISER_FUNC_PITH_CHECK_PREFIX,
@@ -42,19 +46,17 @@ from beartype._check._checksnip import (
     CODE_TESTER_CHECK_PREFIX,
     CODE_GET_FUNC_PITH_VIOLATION,
     CODE_GET_HINT_OBJECT_VIOLATION,
-    CODE_GET_VIOLATION_CLS_STACK,
     CODE_GET_VIOLATION_RANDOM_INT,
     CODE_RAISE_VIOLATION,
     CODE_WARN_VIOLATION,
 )
-from beartype._conf.confcls import (
-    BEARTYPE_CONF_DEFAULT,
-    BeartypeConf,
-)
+from beartype._conf.confmain import BeartypeConf
+from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._conf.conftest import die_unless_conf
 from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN_REPR
-from beartype._data.hint.datahinttyping import (
+from beartype._data.typing.datatypingport import Hint
+from beartype._data.typing.datatyping import (
     CallableRaiser,
     CallableRaiserOrTester,
     CallableTester,
@@ -66,9 +68,8 @@ from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.error.utilerrraise import reraise_exception_placeholder
 from beartype._util.error.utilerrwarn import reissue_warnings_placeholder
 from beartype._util.func.utilfuncmake import make_func
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585ref import (
+from beartype._util.hint.pep.proposal.pep484585.pep484585ref import (
     get_hint_pep484585_ref_names_relative_to)
-from beartype._util.hint.utilhinttest import is_hint_ignorable
 from itertools import count
 from warnings import (
     catch_warnings,
@@ -83,7 +84,7 @@ def make_func_raiser(
     # rather than by keyword. Care should be taken when refactoring parameters,
     # particularly with respect to parameter position.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    hint: object,
+    hint: Hint,
     conf: BeartypeConf,
     exception_prefix: str,
 ) -> CallableRaiser:
@@ -94,6 +95,9 @@ def make_func_raiser(
     this factory and either raising an exception or emitting a warning when that
     object violates that hint).
 
+    This factory underlies the public :func:`beartype.door.die_if_unbearable`
+    type-checking raiser function.
+
     This factory is memoized for efficiency.
 
     Caveats
@@ -104,7 +108,7 @@ def make_func_raiser(
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -142,7 +146,7 @@ def make_func_tester(
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Mandatory parameters.
-    hint: object,
+    hint: Hint,
 
     # Optional parameters.
     conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
@@ -154,11 +158,14 @@ def make_func_tester(
     arbitrary object passed to that tester satisfies the type hint passed to
     this factory and returning that result as its boolean return).
 
+    This factory underlies the public :func:`beartype.door.is_bearable`
+    type-checking tester function.
+
     This factory is memoized for efficiency.
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be type-checked.
     conf : BeartypeConf, optional
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -185,10 +192,117 @@ def make_func_tester(
     )
 
 # ....................{ FACTORIES ~ code                   }....................
+#FIXME: Unit test us up, please.
+@callable_cached
+def make_code_raiser_hint_object_check(
+    hint_sane: HintSane,
+    hint_insane: Hint,
+    conf: BeartypeConf,
+    exception_prefix: str,
+) -> CodeGenerated:
+    '''
+    Pure-Python code snippet of a type-checking raiser function type-checking an
+    arbitrary object against the passed type hint under the passed beartype
+    configuration by either raising a fatal exception *or* emitting a non-fatal
+    warning when that object violates this hint.
+
+    This factory underlies the public :func:`beartype.door.die_if_unbearable`
+    type-checking raiser function.
+
+    This factory is memoized for efficiency.
+
+    Parameters
+    ----------
+    hint_sane : HintSane
+        Metadata encapsulating the type hint to be type-checked.
+    hint_insane : Hint
+        **Insane** (i.e., pre-sanified) type hint to be type-checked.
+    conf : BeartypeConf
+        **Beartype configuration** (i.e., self-caching dataclass encapsulating
+        all settings configuring type-checking for the passed object).
+    exception_prefix : str
+        Human-readable substring prefixing raised exception messages.
+
+    Returns
+    -------
+    CodeGenerated
+        Tuple containing the Python code snippet dynamically generated by this
+        code factory and metadata describing that code. See the
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
+
+    See Also
+    --------
+    :func:`.make_check_expr`
+        Further details.
+    '''
+
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    # CAUTION: Synchronize with the make_code_raiser_func_pith_check() factory.
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+
+    # Python code snippet comprising a single boolean expression type-checking
+    # an arbitrary object against this hint.
+    (
+        code_expr,
+        func_scope,
+        hint_refs_type_basename,
+    ) = make_check_expr(hint_sane, conf)
+
+    # Code snippet passing the value of the random integer previously generated
+    # for the current call to the exception-handling function call embedded in
+    # the "CODE_HINT_ROOT_SUFFIX" snippet, defaulting to *NOT* passing this.
+    arg_random_int = (
+        CODE_GET_VIOLATION_RANDOM_INT
+        if ARG_NAME_GETRANDBITS in func_scope else
+        ''
+    )
+
+    # Pass hidden parameters to this raiser function exposing:
+    # * The passed exception prefix accessed by this snippet.
+    # * The get_hint_object_violation() getter called by the
+    #   "CODE_GET_HINT_OBJECT_VIOLATION" snippet.
+    # * The passed *INSANE* type hint accessed by this snippet. Why insane?
+    #   Because the mere act of sanifying this hint typically reduces this hint
+    #   from having a terse readable to verbose unreadable representation in
+    #   violation messages raised by this raiser function. An insane hint is
+    #   preferable for the purposes of generating readable violations.
+    func_scope[ARG_NAME_EXCEPTION_PREFIX] = exception_prefix
+    func_scope[ARG_NAME_GET_VIOLATION] = get_hint_object_violation
+    func_scope[ARG_NAME_HINT] = hint_insane
+
+    #FIXME: [SPEED] Globalize this bound method as a negligible efficiency gain.
+    # Code snippet generating a human-readable violation exception or warning
+    # when the root pith violates the root type hint.
+    code_get_violation = CODE_GET_HINT_OBJECT_VIOLATION.format(
+        arg_random_int=arg_random_int)
+
+    # Code snippet handling the previously generated violation by either raising
+    # that violation as a fatal exception or emitting that violation as a
+    # non-fatal warning.
+    code_handle_violation = _make_code_raiser_violation(
+        conf=conf, func_scope=func_scope, is_param=None)
+
+    # Code snippet type-checking the root pith against the root hint.
+    func_code = (
+        f'{CODE_RAISER_HINT_OBJECT_CHECK_PREFIX}'
+        f'{code_expr}'
+        f'{code_get_violation}'
+        f'{code_handle_violation}'
+    )
+
+    # Return all metadata required by higher-level callers.
+    return (
+        func_code,
+        func_scope,
+        hint_refs_type_basename,
+    )
+
+
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_tester_check(
-    hint: object,
+    hint_sane: HintSane,
+    hint_insane: Hint,
     conf: BeartypeConf,
     exception_prefix : str,
 ) -> CodeGenerated:
@@ -197,25 +311,30 @@ def make_code_tester_check(
     arbitrary object against the passed type hint under the passed beartype
     configuration by returning whether that object satisfies this hint or not.
 
+    This factory underlies the public :func:`beartype.door.is_bearable`
+    type-checking tester function.
+
     This factory is memoized for efficiency.
 
     Parameters
     ----------
-    hint : object
-        Type hint to be type-checked.
+    hint_sane : HintSane
+        Metadata encapsulating the type hint to be type-checked.
+    hint_insane : Hint
+        **Insane** (i.e., pre-sanified) type hint to be type-checked. Although
+        this factory ignores this hint, alternate factories require this hint.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
     exception_prefix : str
-        Human-readable label prefixing the representation of this object in the
-        exception message.
+        Human-readable substring prefixing raised exception messages.
 
     Returns
     -------
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
 
     See Also
     --------
@@ -229,7 +348,7 @@ def make_code_tester_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint, conf)
+    ) = make_check_expr(hint_sane, conf)
 
     # Code snippet type-checking the root pith against the root hint.
     func_code = f'{CODE_TESTER_CHECK_PREFIX}{code_expr}'
@@ -245,7 +364,7 @@ def make_code_tester_check(
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_raiser_func_pith_check(
-    hint: object,
+    hint_sane: HintSane,
     conf: BeartypeConf,
     cls_stack: Optional[TypeStack],
     is_param: Optional[bool],
@@ -261,8 +380,10 @@ def make_code_raiser_func_pith_check(
 
     Parameters
     ----------
-    hint : object
-        Type hint to be type-checked.
+    hint_sane : HintSane
+        Metadata encapsulating the type hint to be type-checked.
+    hint_insane : Hint
+        **Insane** (i.e., pre-sanified) type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
@@ -278,10 +399,12 @@ def make_code_raiser_func_pith_check(
         If the code snippet generated and returned by this factory is
         type-checking a previously localized:
 
-        * Parameter of a decorated callable, :data:`True`.
-        * Return of a decorated callable, :data:`False`.
+        * Parameter of a decorated callable, this parameter should be
+          :data:`True`.
+        * Return of a decorated callable, this parameter should be
+          :data:`False`.
         * Arbitrary object passed to the :func:`beartype.door.die_if_unbearable`
-          type-checker, :data:`None`.
+          type-checker,  this parameter should be :data:`None`.
 
         Defaults to :data:`None`.
 
@@ -290,7 +413,7 @@ def make_code_raiser_func_pith_check(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
 
     See Also
     --------
@@ -308,7 +431,7 @@ def make_code_raiser_func_pith_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint, conf, cls_stack)
+    ) = make_check_expr(hint_sane, conf, cls_stack)
 
     # Code snippet passing the value of the random integer previously generated
     # for the current call to the exception-handling function call embedded in
@@ -319,19 +442,16 @@ def make_code_raiser_func_pith_check(
         ''
     )
 
-    # Code snippet passing the current class stack if needed to type-check this
-    # type hint, defaulting to *NOT* passing this.
-    arg_cls_stack = CODE_GET_VIOLATION_CLS_STACK if cls_stack else ''
-
-    # Pass hidden parameters to this raiser function exposing the
-    # get_func_pith_violation() getter called by the
-    # "CODE_GET_FUNC_PITH_VIOLATION" snippet.
+    # Expose the get_func_pith_violation() getter called by the
+    # "CODE_GET_FUNC_PITH_VIOLATION" snippet as a "beartype"-specific hidden
+    # parameter passed to this wrapper function.
     func_scope[ARG_NAME_GET_VIOLATION] = get_func_pith_violation
 
+    #FIXME: [SPEED] Globalize CODE_GET_FUNC_PITH_VIOLATION.format() as
+    #"CODE_GET_FUNC_PITH_VIOLATION_format". *sigh*
     # Code snippet generating a human-readable violation exception or warning
     # when the root pith violates the root type hint.
     code_get_violation = CODE_GET_FUNC_PITH_VIOLATION.format(
-        arg_cls_stack=arg_cls_stack,
         arg_random_int=arg_random_int,
         pith_name=CODE_PITH_ROOT_NAME_PLACEHOLDER,
     )
@@ -381,7 +501,7 @@ def make_code_raiser_func_pep484_noreturn_check(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
     '''
 
     # Lexical scope to be returned, initialized to the empty dictionary.
@@ -395,7 +515,6 @@ def make_code_raiser_func_pep484_noreturn_check(
     # Code snippet generating a human-readable violation exception or warning
     # when the root pith violates the root type hint.
     code_get_violation = CODE_GET_FUNC_PITH_VIOLATION.format(
-        arg_cls_stack='',
         arg_random_int='',
         pith_name=ARG_NAME_RETURN_REPR,
     )
@@ -416,102 +535,6 @@ def make_code_raiser_func_pep484_noreturn_check(
         (),  # Irrelevant "hint_refs_type_basename" tuple item. Chug it!
     )
 
-
-#FIXME: Unit test us up, please.
-@callable_cached
-def make_code_raiser_hint_object_check(
-    hint: object,
-    conf: BeartypeConf,
-    exception_prefix: str,
-) -> CodeGenerated:
-    '''
-    Pure-Python code snippet of a type-checking raiser function type-checking an
-    arbitrary object against the passed type hint under the passed beartype
-    configuration by either raising a fatal exception *or* emitting a non-fatal
-    warning when that object violates this hint.
-
-    This factory is memoized for efficiency.
-
-    Parameters
-    ----------
-    hint : object
-        Type hint to be type-checked.
-    conf : BeartypeConf
-        **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all settings configuring type-checking for the passed object).
-    exception_prefix : str
-        Human-readable label prefixing the representation of this object in the
-        exception message.
-
-    Returns
-    -------
-    CodeGenerated
-        Tuple containing the Python code snippet dynamically generated by this
-        code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
-
-    See Also
-    --------
-    :func:`.make_check_expr`
-        Further details.
-    '''
-
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # CAUTION: Synchronize with the make_code_raiser_func_pith_check() factory.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-
-    # Python code snippet comprising a single boolean expression type-checking
-    # an arbitrary object against this hint.
-    (
-        code_expr,
-        func_scope,
-        hint_refs_type_basename,
-    ) = make_check_expr(hint, conf)
-
-    # Code snippet passing the value of the random integer previously generated
-    # for the current call to the exception-handling function call embedded in
-    # the "CODE_HINT_ROOT_SUFFIX" snippet, defaulting to *NOT* passing this.
-    arg_random_int = (
-        CODE_GET_VIOLATION_RANDOM_INT
-        if ARG_NAME_GETRANDBITS in func_scope else
-        ''
-    )
-
-    # Pass hidden parameters to this raiser function exposing:
-    # * The passed exception prefix accessed by this snippet.
-    # * The get_hint_object_violation() getter called by the
-    #   "CODE_GET_HINT_OBJECT_VIOLATION" snippet.
-    # * The passed type hint accessed by this snippet.
-    func_scope[ARG_NAME_EXCEPTION_PREFIX] = exception_prefix
-    func_scope[ARG_NAME_GET_VIOLATION] = get_hint_object_violation
-    func_scope[ARG_NAME_HINT] = hint
-
-    # Code snippet generating a human-readable violation exception or warning
-    # when the root pith violates the root type hint.
-    code_get_violation = CODE_GET_HINT_OBJECT_VIOLATION.format(
-        arg_random_int=arg_random_int)
-
-    # Code snippet handling the previously generated violation by either raising
-    # that violation as a fatal exception or emitting that violation as a
-    # non-fatal warning.
-    code_handle_violation = _make_code_raiser_violation(
-        conf=conf, func_scope=func_scope, is_param=None)
-
-    # Code snippet type-checking the root pith against the root hint.
-    func_code = (
-        f'{CODE_RAISER_HINT_OBJECT_CHECK_PREFIX}'
-        f'{code_expr}'
-        f'{code_get_violation}'
-        f'{code_handle_violation}'
-    )
-
-    # Return all metadata required by higher-level callers.
-    return (
-        func_code,
-        func_scope,
-        hint_refs_type_basename,
-    )
-
 # ....................{ PRIVATE ~ globals                  }....................
 _func_checker_name_counter = count(start=0, step=1)
 '''
@@ -540,7 +563,7 @@ def _func_checker_ignorable(obj: object) -> bool:
 #FIXME: Unit test us up, please.
 def _make_func_checker(
     # Mandatory parameters.
-    hint: object,
+    hint: Hint,
     conf: BeartypeConf,
     make_code_check: Callable[..., CodeGenerated],
 
@@ -549,8 +572,8 @@ def _make_func_checker(
 ) -> CallableRaiserOrTester:
     '''
     **Type-checking function factory** (i.e., low-level callable dynamically
-    generating a pure-Python tester function testing whether an arbitrary object
-    passed to that tester satisfies the type hint passed to this factory and
+    generating a pure-Python function detecting whether an arbitrary object
+    passed to that function satisfies the type hint passed to this factory and
     either returning that result as its boolean return *or* raising a fatal
     exception or emitting a non-fatal warning if that result is :data:`False`).
 
@@ -566,7 +589,7 @@ def _make_func_checker(
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -576,8 +599,8 @@ def _make_func_checker(
         code snippet of a function type-checking an arbitrary object against the
         passed type hint under the passed beartype configuration).
     exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to a reasonably sensible string.
+        Human-readable substring prefixing raised exception messages. Defaults
+        to a reasonably sensible string.
 
     Returns
     -------
@@ -607,6 +630,11 @@ def _make_func_checker(
     assert callable(make_code_check), f'{repr(make_code_check)} uncallable.'
 
     # Attempt to...
+    #
+    # Note that the passed "exception_prefix" is intentionally *NOT* passed to
+    # functions in the body of this "try" block. Why? Memoization efficiency.
+    # Instead, the placeholder "EXCEPTION_PLACEHOLDER" is intentionally passed.
+    # The "except" block then catches and replaces that with "exception_prefix".
     try:
         # With a context manager "catching" *ALL* non-fatal warnings emitted
         # during this logic for subsequent "playback" below...
@@ -616,20 +644,20 @@ def _make_func_checker(
             die_unless_conf(conf)
             # Else, "conf" is a configuration.
 
-            # Either:
-            # * If this hint is PEP-noncompliant, the PEP-compliant type hint
-            #   converted from this PEP-noncompliant type hint.
-            # * If this hint is PEP-compliant and supported, this hint as is.
-            # * Else, raise an exception (i.e., if this hint is neither
-            #   PEP-noncompliant nor a supported PEP-compliant hint).
+            # Sane hint sanified from this possibly insane parameter hint if
+            # sanifying this hint generated no supplementary metadata *OR*
+            # that metadata otherwise. Additionally, if this hint is
+            # unsupported by @beartype, raise an exception.
             #
             # Do this first *BEFORE* passing this hint to any further callables.
-            hint = sanify_hint_root_statement(
+            hint_sane = sanify_hint_root_statement(
                 hint=hint, conf=conf, exception_prefix=EXCEPTION_PLACEHOLDER)
+            # print(f'Reduced tester root hint {repr(hint)} to hint or metadata {repr(hint_sane)}.')
 
             # If this hint is ignorable, all objects satisfy this hint. In this
             # case, return a trivial function unconditionally returning true.
-            if is_hint_ignorable(hint):
+            if hint_sane is HINT_SANE_IGNORABLE:
+                # print(f'[_make_func_checker] Ignoring ignorable hint {hint} with conf {conf}!')
                 return _func_checker_ignorable
             # Else, this hint is unignorable.
 
@@ -640,7 +668,48 @@ def _make_func_checker(
                 code_check,
                 func_scope,
                 hint_refs_type_basename,
-            ) = make_code_check(hint, conf, exception_prefix)
+            ) = make_code_check(hint_sane, hint, conf, exception_prefix)
+            # print(f'func_scope: {func_scope}')
+
+            #FIXME: Actually, nothing below is particularly significant. Users
+            #now basically require this. So, let's find a way to do this. The
+            #only genuinely significant blocker here from @beartype's
+            #perspective is *MEMOIZATION.* Currently, the parent factories
+            #(e.g., make_func_raiser()) transitively calling this factory are
+            #memoized by @callable_cached. Clearly, memoization breaks down in
+            #the face of relative forward references... *OR DOES IT!?* We now
+            #need to probably:
+            #* Figure out a way of replacing all relative forward references
+            #  with corresponding "ForwardRefRelativeProxy" objects.
+            #* This is a fundamentally new type of thing we currently do *NOT*
+            #  have. The idea here is that these objects should dynamically
+            #  introspect up the call stack for the first stack frame residing
+            #  in a non-"beartype" module, which these objects then resolve each
+            #  relative forward reference against.
+            #* Consider refactoring our "codemain" algorthm to unconditionally
+            #  do this for *ALL* relative forward references. Doing so would
+            #  (probably) be a lot faster than the current global string
+            #  replacement approach... maybe. Okay, maybe not. But maybe.
+            #
+            #Sounds fun! Sounds like a lot of non-trivial work, too. But that's
+            #where all the fun resides, doesn't it? *DOESN'T IT!?*
+            #FIXME: *WAIT.* That doesn't quite work. The issue, of course, is
+            #that the scope in which a callable is called may no longer have
+            #access to the scope in which a callable was defined, which is where
+            #the class referred to by relative forward references actually
+            #lives. So, we absolutely should *NOT* "Consider refactoring our..."
+            #No. Don't do that. That said, the above idea *SHOULD* still behave
+            #itself for if_bearable() and die_if_unbearable(), because these
+            #statement-level type-checkers actually do run in the same scopes
+            #that their type hints are defined in. Huh. Pretty nifty, eh? This
+            #then suggests that:
+            #* We'll need to generalize our "codemain" function to accept a new
+            #  optional "is_refs_relative_proxy: bool = False" parameter. When:
+            #  * "True", code generation replaces all relative forward
+            #    references with corresponding "ForwardRefRelativeProxy" objects
+            #    as detailed above.
+            #  * "False", code generation simply returns relative forward
+            #    references as it currently does.
 
             # If this hint contains one or more relative forward references,
             # this hint is non-portable across lexical scopes. In this case,
@@ -704,11 +773,12 @@ def _make_func_checker(
 
             # ....................{ FUNCTION               }....................
             # Type-checking tester function to be returned.
+            # print(f'Making checker {repr(func_checker_name)} with conf {conf}...')
             func_tester = make_func(
                 func_name=func_checker_name,
                 func_code=func_checker_code,
                 func_locals=func_scope,
-                func_label='die_if_unbearable() or is_bearable() type-checker',
+                func_label=EXCEPTION_PLACEHOLDER,
                 is_debug=conf.is_debug,
             )
         # If one or more warnings were issued, reissue these warnings with each
@@ -777,7 +847,7 @@ def _make_code_raiser_violation(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint for
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint for
         details.
 
     Raises
@@ -846,9 +916,8 @@ def _make_code_raiser_violation(
         # wrapper function wraps. Needlessly passing issue_warning() rather than
         # warn() here would only consume CPU cycles for *NO* tangible gain.
         func_scope[ARG_NAME_WARN] = warn
-    # Else...
+    # Else, raise a fatal exception.
     else:
-        # Raise a fatal exception.
         code_violation = CODE_RAISE_VIOLATION
 
     # Return this code snippet.
