@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -11,11 +11,14 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype.typing import Iterable as typing_Iterable
-from beartype._data.hint.datahinttyping import IterableStrs
+from beartype._data.typing.datatyping import (
+    BoolTristate,
+    IterableStrs,
+    IterableTypes,
+)
 from collections.abc import (
-    Iterable,
-    Sequence,
+    Iterable as IterableABC,
+    Sequence as SequenceABC,
 )
 
 # ....................{ JOINERS                            }....................
@@ -72,21 +75,21 @@ def join_delimited(
         to :data:`False`.
 
     Returns
-    ----------
+    -------
     str
         Concatenation of these strings.
 
     Examples
-    ----------
+    --------
         >>> join_delimited(
         ...     strs=('Fulgrim', 'Perturabo', 'Angron', 'Mortarion'),
         ...     delimiter_if_two=' and ',
         ...     delimiter_if_three_or_more_nonlast=', ',
-        ...     delimiter_if_three_or_more_last=', and '
+        ...     delimiter_if_three_or_more_last=', and ',
         ... )
         'Fulgrim, Perturabo, Angron, and Mortarion'
     '''
-    assert isinstance(strs, Iterable) and not isinstance(strs, str), (
+    assert isinstance(strs, IterableABC) and not isinstance(strs, str), (
         f'{repr(strs)} not non-string iterable.')
     assert isinstance(delimiter_if_two, str), (
         f'{repr(delimiter_if_two)} not string.')
@@ -97,7 +100,7 @@ def join_delimited(
 
     # If this iterable is *NOT* a sequence, internally coerce this iterable
     # into a sequence for subsequent indexing purposes.
-    if not isinstance(strs, Sequence):
+    if not isinstance(strs, SequenceABC):
         strs = tuple(strs)
     # Else, this iterable is already a sequence.
     #
@@ -132,6 +135,50 @@ def join_delimited(
     # Return these two substrings, delimited appropriately.
     return f'{strs_nonlast}{delimiter_if_three_or_more_nonlast}{strs_last}'
 
+# ....................{ JOINERS ~ conjunction              }....................
+#FIXME: Unit test us up, please.
+def join_delimited_conjunction(strs: IterableStrs, **kwargs) -> str:
+    '''
+    Concatenate the passed iterable of zero or more strings delimited by commas
+    and/or the conjunction "and" (conditionally depending on both the length of
+    this iterable and index of each string in this iterable), yielding a
+    human-readable string listing arbitrarily many substrings conjunctively.
+
+    Specifically, this function returns either:
+
+    * If this iterable contains no strings, the empty string.
+    * If this iterable contains one string, this string as is is unmodified.
+    * If this iterable contains two strings, these strings delimited by the
+      conjunction "and".
+    * If this iterable contains three or more strings, a string listing these
+      contained strings such that:
+
+      * All contained strings except the last two are suffixed by commas.
+      * The last two contained strings are delimited by the conjunction "and".
+
+    Parameters
+    ----------
+    strs : Iterable[str]
+        Iterable of all strings to be concatenated conjunctively.
+
+    All remaining keyword parameters are passed as is to the lower-level
+    :func:`.join_delimeted` function underlying this higher-level function.
+
+    Returns
+    -------
+    str
+        Conjunctive concatenation of these strings.
+    '''
+
+    # One of us. We accept one-liner. One of us.
+    return join_delimited(
+        strs=strs,
+        delimiter_if_two=' and ',
+        delimiter_if_three_or_more_nonlast=', ',
+        delimiter_if_three_or_more_last=', and ',
+        **kwargs
+    )
+
 # ....................{ JOINERS ~ disjunction              }....................
 def join_delimited_disjunction(strs: IterableStrs, **kwargs) -> str:
     '''
@@ -161,7 +208,7 @@ def join_delimited_disjunction(strs: IterableStrs, **kwargs) -> str:
     :func:`.join_delimeted` function underlying this higher-level function.
 
     Returns
-    ----------
+    -------
     str
         Disjunctive concatenation of these strings.
     '''
@@ -176,7 +223,13 @@ def join_delimited_disjunction(strs: IterableStrs, **kwargs) -> str:
     )
 
 
-def join_delimited_disjunction_types(types: typing_Iterable[type]) -> str:
+def join_delimited_disjunction_types(
+    # Mandatory parameters.
+    types: IterableTypes,
+
+    # Optional parameters.
+    is_color: BoolTristate = False,
+) -> str:
     '''
     Concatenate the human-readable classname of each class in the passed
     iterable delimited by commas and/or the disjunction "or" (conditionally
@@ -189,9 +242,13 @@ def join_delimited_disjunction_types(types: typing_Iterable[type]) -> str:
     types : Iterable[type]
         Iterable of all classes whose human-readable classnames are to be
         concatenated disjunctively.
+    is_color : BoolTristate, optional
+        Tri-state colouring boolean governing ANSI usage. See the
+        :attr:`beartype.BeartypeConf.is_color` attribute for further details.
+        Defaults to :data:`False`.
 
     Returns
-    ----------
+    -------
     str
         Disjunctive concatenation of these classnames.
     '''
@@ -200,4 +257,5 @@ def join_delimited_disjunction_types(types: typing_Iterable[type]) -> str:
     from beartype._util.text.utiltextlabel import label_type
 
     # Make it so, ensign.
-    return join_delimited_disjunction(label_type(cls) for cls in types)
+    return join_delimited_disjunction(
+        label_type(cls=cls, is_color=is_color) for cls in types)
