@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -13,8 +13,9 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.door._cls.pep.pep484.doorpep484class import ClassTypeHint
+from beartype._data.typing.datatypingport import Hint
 from beartype._util.cls.utilclsmake import make_type
-from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
+from beartype._util.hint.pep.proposal.pep484.pep484newtype import (
     get_hint_pep484_newtype_alias)
 
 # ....................{ SUBCLASSES                         }....................
@@ -25,7 +26,7 @@ class NewTypeTypeHint(ClassTypeHint):
     '''
 
     # ..................{ INITIALIZERS                       }..................
-    def __init__(self, hint: object) -> None:
+    def __init__(self, hint: Hint) -> None:
 
         # Initialize the superclass with all passed parameters.
         super().__init__(hint)
